==> dvcompute_mpi-1.3.3.crate: dvcompute_mpi-1.3.3/README.md <==
# dvcompute_mpi

This crate is a part of discrete event simulation framework DVCompute Simulator (registration
number 2021660590 of Rospatent). The crate implements the network interface, which is meant
to be built on top of some MPI implementation that you are going to use within distributed
simulation. But you are not obliged to use MPI, though.

In general, there are the following main crates: `dvcompute` (for sequential simulation),
`dvcompute_dist` (for optimistic distributed simulation - from multicore computers till supercomputers),
`dvcompute_cons` (for conservative distributed simulation - from multicore computers till supercomputers) and
`dvcompute_branch` (for nested simulation - theory of games, estimation of the optimal strategy). All four crates are
very close. They are based on the same method.

## Requirements

It is expected that the `dvcompute_mpi` dynamic (shared) library can be found by the operating
system, when launching the executable file of the simulation model. You can build the `dvcompute_mpi`
library yourself from <https://github.com/dsorokin/dvcompute/src/dvcompute_mpi_cdylib> sources
that require CMake, C++ compiler and some MPI implementation that you are going to use.
Because of specific MPI implementation, this library cannot be unified. The library obeys
the predefined binary interface that you can implement yourself in theory, which means that
MPI is not actually obligatory.

## Documentation

* [API docs](https://docs.rs/dvcompute_mpi/)

## Licence

Copyright 2020-2022 David Sorokin <david.sorokin@gmail.com>, based in Yoshkar-Ola, Russia

This software is subject to the terms of the Mozilla Public
License, v. 2.0. If a copy of the MPL was not distributed with this
file, You can obtain one at <http://mozilla.org/MPL/2.0/>.

==> dvcompute_mpi-2.0.0.crate: dvcompute_mpi-2.0.0/README.md <==
# dvcompute_mpi

This crate is a part of discrete event simulation framework DVCompute Simulator (registration
number 2021660590 of Rospatent). The crate implements the network interface, which is meant
to be built on top of some MPI implementation that you are going to use within distributed
simulation. But you are not obliged to use MPI, though.

In general, there are the following main crates: `dvcompute` (for sequential simulation),
`dvcompute_dist` (for optimistic distributed simulation - from multicore computers till supercomputers),
`dvcompute_cons` (for conservative distributed simulation - from multicore computers till supercomputers) and
`dvcompute_branch` (for nested simulation - theory of games, estimation of the optimal strategy). All four crates are
very close. They are based on the same method.

## Requirements

It is expected that the `dvcompute_mpi` dynamic (shared) library can be found by the operating
system, when launching the executable file of the simulation model. You can build the `dvcompute_mpi`
library yourself from <https://github.com/dsorokin/dvcompute/tree/main/src/dvcompute_mpi_cdylib> sources
that require CMake, C++ compiler and some MPI implementation that you are going to use.
Because of specific MPI implementation, this library cannot be unified. The library obeys
the predefined binary interface that you can implement yourself in theory, which means that
MPI is not actually obligatory.

## Documentation

* [API docs](https://docs.rs/dvcompute_mpi/)

## Licence

Copyright 2020-2022 David Sorokin <david.sorokin@gmail.com>, based in Yoshkar-Ola, Russia

This software is subject to the terms of the Mozilla Public
License, v. 2.0. If a copy of the MPL was not distributed with this
file, You can obtain one at <http://mozilla.org/MPL/2.0/>.
